import { describe, test, expect } from 'vitest';
import { isApiUrlAllowed } from './validation.js';
describe('isApiUrlAllowed()', () => {
    test('should allow wix.com URLs', () => {
        expect(isApiUrlAllowed('https://wix.com/_api/service')).toEqual({
            isAllowed: true
        });
    });
    test('should allow dev.wix.com URLs', () => {
        expect(isApiUrlAllowed('https://dev.wix.com/_api/service')).toEqual({
            isAllowed: true
        });
    });
    test('should allow manage.wix.com URLs', () => {
        expect(isApiUrlAllowed('https://manage.wix.com/_api/service')).toEqual({
            isAllowed: true
        });
    });
    test('should allow editor.wix.com URLs', () => {
        expect(isApiUrlAllowed('https://editor.wix.com/_api/service')).toEqual({
            isAllowed: true
        });
    });
    test('should allow wixapis.com URLs', () => {
        expect(isApiUrlAllowed('https://wixapis.com/service')).toEqual({
            isAllowed: true
        });
    });
    test('should return an error if the URL is not from a valid domain', () => {
        expect(isApiUrlAllowed('https://not-wix.com/api')).toEqual({
            isAllowed: false,
            error: expect.stringContaining('Unsupported URL domain: not-wix.com.')
        });
    });
    test('should not allow subdomain attacks', () => {
        expect(isApiUrlAllowed('https://wix.com.evil-domain.com/api')).toEqual({
            isAllowed: false,
            error: expect.stringContaining('Unsupported URL domain: wix.com.evil-domain.com.')
        });
    });
});
//# sourceMappingURL=validation.test.js.map