import { logger } from '../infra/logger.js';
import { GET_ARTICLE_CONTENT_URL } from '../constants.js';
async function fetchArticleContentFromDigor(httpClient, articleUrl, mode, stripHeader = false) {
    // https://dev.wix.com/rawdocs/api/get-article-content?articleUrl=https://dev.wix.com/docs/rest/business-solutions/blog/draft-posts/create-draft-post&schema=true
    const url = new URL(GET_ARTICLE_CONTENT_URL);
    url.searchParams.set('articleUrl', articleUrl);
    const schema = mode === 'methodSchema' ? 'true' : 'false';
    url.searchParams.set('schema', schema);
    logger.log(`Fetching resource from docs ${url.toString()}`);
    const { data } = await httpClient.get(url.toString());
    logger.log(`Fetched resource from docs: ${data.articleContent}`);
    const headerDivider = '## Article Content:'; // after the header, the content starts
    if (stripHeader) {
        const headerIndex = data.articleContent.indexOf(headerDivider);
        if (headerIndex !== -1) {
            return data.articleContent.substring(headerIndex + headerDivider.length);
        }
    }
    return data.articleContent;
}
export async function fetchArticleContent(httpClient, articleUrl, mode, stripHeader = false) {
    if (mode === 'raw') {
        let parsedUrl;
        try {
            parsedUrl = new URL(articleUrl);
        }
        catch {
            throw new Error(`Invalid URL format: ${articleUrl}`);
        }
        const hostname = parsedUrl.hostname.replace('www.', '');
        if (hostname !== 'dev.wix.com') {
            throw new Error(`Unsupported URL domain: ${hostname}. Article URL must be from dev.wix.com`);
        }
        const { data: doc } = await httpClient.get(articleUrl);
        return doc;
    }
    return fetchArticleContentFromDigor(httpClient, articleUrl, mode, stripHeader);
}
//# sourceMappingURL=fetch-article.js.map