import { fetchArticleContent } from './fetch-article.js';
const docURLs = [
    {
        url: 'https://dev.wix.com/docs/picasso/wix-ai-docs/index/get-to-know-wix-llm-instructions',
        action: 'include'
    },
    {
        url: 'https://dev.wix.com/docs/picasso/wix-ai-docs/index/wix-concepts',
        action: 'include'
    },
    {
        url: 'https://dev.wix.com/docs/picasso/wix-ai-docs/index/wix-business-solutions',
        action: 'index',
        title: 'Wix Business Solutions',
        description: `This document provides an overview of the all business solutions available in Wix.
  
Use this document under the following scenarios:
1. The user asks general questions about Wix business solutions.
2. The user asks about a specific business solution, and you want to provide a high-level overview of it.
3. The user looks for a specific business solution, and you want to provide a list of all available solutions.

Please note that this is a large document. Only use it for the scenarios mentioned above.`
    },
    {
        url: 'https://dev.wix.com/docs/picasso/wix-ai-docs/index/wix-business-solutions-recipes',
        action: 'include'
    }
];
const DESCRIPTION = `# Tool: WixREADME

**Directive:** \`WixREADME\` is the **MANDATORY FIRST STEP** for all Wix-related tasks. Its output (including relevant linked documents) provides foundational context for all other Wix tools. Adherence to this protocol is **NON-NEGOTIABLE**.

**Operational Protocol (Strictly Sequential):**

1.  **Execute \`WixREADME\`:**
    * **Action:** Invoke \`WixREADME\`.
    * **Constraint:** MUST complete successfully. NO other Wix tool before this.

2.  **Process \`WixREADME\` Output (Link Identification & Relevance Assessment):**
    * **A. Identify Candidate Links:** Scan \`WixREADME\` output. Extract *only* URLs found within \`<urls>{urls}</urls>\` tags. Ignore all other URLs.
    * **B. Assess Relevance:** For EACH candidate URL from (A), assess its relevance to the **current user's specific prompt/task**.
    * **Outcome:** A list of *relevant* document URLs. If no links are found in \`<urls>\` tags or none are deemed relevant, note this and proceed to Step 4.

3.  **Fetch Relevant Documents (via \`ReadFullDocsArticle\`):**
    * **Condition:** ONLY if Step 2B identified one or more *relevant* URLs.
    * **Action:** For EACH *relevant* URL, invoke \`ReadFullDocsArticle\` to fetch its full content.
    * **Constraint:** All *relevant* documents MUST be fetched before Step 4.

4.  **Proceed with Other Wix Tools:**
    * **Condition:** ONLY after completing Steps 1, 2, and 3 (if Step 3 was applicable).
    * **Action:** Use other Wix tools as needed, utilizing the full context from \`WixREADME\` and fetched relevant documents.

**Summary of Critical Rules:**
* \`WixREADME\` is **ALWAYS FIRST**.
* Analyze \`WixREADME\` output: Extract links *only* from \`<urls>{urls}</urls>\` tags.
* Assess relevance of *each* extracted link against the user's current task.
* Fetch **ONLY RELEVANT** linked documents using \`ReadFullDocsArticle\` before any other Wix tool.
* **FAILURE TO FOLLOW THIS EXACT SEQUENCE WILL LEAD TO ERRORS.** Strict adherence is mandatory.`;
export const WixREADME_DEPENDENT_DESCRIPTION = "**Dependency:** Must be used after 'WixREADME' has successfully run.";
export async function addGetToKnowTools(server) {
    server.tool('WixREADME', DESCRIPTION, async ({ httpClient }) => {
        try {
            const contents = await Promise.all(docURLs.map(async ({ url, action, description, title }) => {
                if (action === 'index') {
                    return {
                        type: 'text',
                        text: `## ${title}\n\n<urls>\n${url}\n</urls>\n\n${description}`
                    };
                }
                const content = await fetchArticleContent(httpClient, url, 'article', true);
                return {
                    type: 'text',
                    text: content
                };
            }));
            return {
                content: contents
            };
        }
        catch (error) {
            return {
                isError: true,
                content: [
                    {
                        type: 'text',
                        text: `Error fetching the document: ${error.message}`
                    }
                ]
            };
        }
    });
}
//# sourceMappingURL=get-to-know.js.map