import fs from 'fs/promises';
import path from 'path';
import { homedir } from 'os';
const createNullLogger = () => {
    return {
        log: () => { },
        error: () => { }
    };
};
const createStdErrLogger = () => {
    return {
        log: (data) => {
            console.error(data);
        },
        error: (data) => {
            console.error(data);
        }
    };
};
const createMcpServerLogger = (server) => {
    return {
        log: (data) => {
            server.server.sendLoggingMessage({ level: 'info', data });
        },
        error: (data) => {
            server.server.sendLoggingMessage({ level: 'error', data });
        }
    };
};
const createFileLogger = () => {
    const filePath = path.join(homedir(), 'wix-mcp-log.txt');
    const date = new Date()
        .toLocaleString('en-US', { timeZone: 'Asia/Jerusalem' })
        .replace(/,/g, '');
    return {
        log: (...data) => {
            const message = `[info] ${date} - ${data.join(' ')}`;
            fs.appendFile(filePath, `${message}\n`);
        },
        error: (...data) => {
            const message = `[error] ${date} - ${data.join(' ')}`;
            fs.appendFile(filePath, `${message}\n`);
        }
    };
};
export const logger = createNullLogger();
export const attachMcpServerLogger = (server) => {
    const mcpLogger = createMcpServerLogger(server);
    logger.log = mcpLogger.log;
    logger.error = mcpLogger.error;
};
export const attachStdErrLogger = () => {
    const stdErrLogger = createStdErrLogger();
    logger.log = stdErrLogger.log;
    logger.error = stdErrLogger.error;
};
export const attachFileLogger = () => {
    const fileLogger = createFileLogger();
    logger.log = fileLogger.log;
    logger.error = fileLogger.error;
};
//# sourceMappingURL=logger.js.map