import stripAnsi from 'strip-ansi';
import eventually from './eventually.js';
import { logger } from '../infra/logger.js';
export function handleStdout(stdout) {
    let checkStartIndex = 0;
    const lines = [];
    logger.log(`handleStdout: stdout: ${stdout}`);
    stdout.on('data', (chunk) => {
        logger.log(`handleStdout: chunk: ${chunk}`);
        // log(`create-cli: chunk: ${chunk}`);
        lines.push(...stripAnsi(chunk.toString()).split('\n'));
    });
    return {
        async waitForText(match, { timeout = 2 * 60 * 1000 } = {}) {
            return eventually(() => {
                const matchedIndex = lines.findIndex((line, index) => {
                    if (index < checkStartIndex) {
                        return false;
                    }
                    if (typeof match === 'string') {
                        return line.includes(match);
                    }
                    return line.match(match);
                });
                checkStartIndex = matchedIndex >= 0 ? matchedIndex + 1 : lines.length;
                if (matchedIndex !== -1) {
                    return lines[matchedIndex];
                }
                const message = `Could not match text in output: ${match}`;
                throw new Error(message);
            }, { timeout });
        },
        async waitForAndCallback(matchesAndCallbacks, { timeout = 2 * 60 * 1000 } = {}) {
            let stopResolve;
            const stopPromise = new Promise((resolve) => {
                stopResolve = resolve;
            });
            // Keep track of matches we've already processed
            const processedMatches = new Set();
            const waitPromise = eventually(() => {
                //log(`create-cli: waiting for ${matchesAndCallbacks.length - processedMatches.size} matches`);
                for (const { match, callback } of matchesAndCallbacks) {
                    // Skip if we've already processed this match
                    if (processedMatches.has(match)) {
                        continue;
                    }
                    if (lines.some((line) => line.includes(match))) {
                        logger.log(`create-cli: found match ${match}`);
                        // Add to processed matches so we don't match it again
                        processedMatches.add(match);
                        callback(() => {
                            logger.log(`create-cli: stopping match loop`);
                            stopResolve();
                        });
                    }
                    else {
                        // log(`create-cli: waiting for ${match}`);
                    }
                }
                // If we've processed all matches, we're done
                if (processedMatches.size === matchesAndCallbacks.length) {
                    return true;
                }
                throw new Error(`Could not find any of the remaining matches: ${matchesAndCallbacks
                    .filter((m) => !processedMatches.has(m.match))
                    .map((m) => m.match)
                    .join(', ')}`);
            }, { timeout });
            return Promise.race([waitPromise, stopPromise]);
        },
        async getOutput() {
            return lines.join('\n');
        }
    };
}
//# sourceMappingURL=handleStdout.js.map