import { handleStdout } from './handleStdout.js';
import { logger } from '../infra/logger.js';
export const ENTER = '\r';
const DOWN = '\u001b[B';
export const mockInteractiveGenerateCommandTool = async ({ extensionType, stdin, stdout }) => {
    try {
        logger.log('RunWixCliCommand: handle stdout');
        const stdoutHandler = handleStdout(stdout);
        logger.log('RunWixCliCommand: waiting for text');
        await stdoutHandler.waitForText('What kind of extension would you like to generate?');
        // Enter the extension type
        if (extensionType === 'DASHBOARD_PAGE') {
            // No need to press enter
        }
        else if (extensionType === 'BACKEND_EVENT') {
            logger.log('RunWixCliCommand: writing DOWN 9 times');
            for (let i = 0; i < 9; i++) {
                stdin.write(DOWN);
                await new Promise((resolve) => setTimeout(resolve, 10));
            }
        }
        logger.log('RunWixCliCommand: writing ENTER 1');
        stdin.write(ENTER);
        // Wait for next step
        if (extensionType === 'DASHBOARD_PAGE') {
            await stdoutHandler.waitForText('Page title');
            logger.log('RunWixCliCommand: writing ENTER 2');
            stdin.write(ENTER);
            await stdoutHandler.waitForText('Enter the route for the new page');
            logger.log('RunWixCliCommand: writing ENTER 3');
            stdin.write(ENTER);
        }
        else if (extensionType === 'BACKEND_EVENT') {
            await stdoutHandler.waitForText('Event folder');
            logger.log('RunWixCliCommand: writing ENTER 2');
            stdin.write(ENTER);
            logger.log('RunWixCliCommand: waiting for text');
            // Check if the text is "Would you like to install dependencies now?", if dependencies are already installed, it will not be printed
            try {
                await stdoutHandler.waitForText('Would you like to install dependencies now?', { timeout: 1000 });
                logger.log('RunWixCliCommand: writing ENTER 3');
                stdin.write(ENTER);
            }
            catch (error) {
                if (error instanceof Error &&
                    error.message.includes('Could not match text in output')) {
                    logger.log('RunWixCliCommand: dependencies are already installed, skipping install');
                    logger.log(await stdoutHandler.getOutput());
                }
                else {
                    throw error;
                }
            }
        }
        logger.log('RunWixCliCommand: waiting for success message');
        try {
            await stdoutHandler.waitForText('Successfully', { timeout: 1000 });
            logger.log('RunWixCliCommand: success message found');
        }
        catch (error) {
            if (error instanceof Error &&
                error.message.includes('Could not match text in output')) {
                logger.log('RunWixCliCommand: success message not found, skipping'); // just skip and try to continue by returning the output
            }
            else {
                throw error;
            }
        }
        return stdoutHandler.getOutput();
    }
    catch (error) {
        logger.error('RunWixCliCommand: error', error);
        throw error;
    }
};
//# sourceMappingURL=interactive-command-utils.js.map