import { logger } from '../infra/logger.js';
import { GET_ARTICLE_CONTENT_URL, PORTAL_INDEX_URL } from '../constants.js';
const getPortalIndex = async (portalName) => {
    const response = await fetch(`${PORTAL_INDEX_URL}?portalName=${portalName}`);
    const data = await response.json();
    return data;
};
const addPortalResources = async (server, portalName) => {
    // get portal index:
    const portalIndexResponse = await getPortalIndex(portalName);
    logger.log(`portalIndexResponse for ${portalName}`, JSON.stringify(portalIndexResponse, null, 2));
    // for each portalIndex entry, add a resource to the server:
    for (const entry of portalIndexResponse.portalIndex) {
        logger.log(`entry ${JSON.stringify(entry, null, 2)}`);
        const name = entry.url;
        const uri = entry.url.replace('https://dev.wix.com/docs/', 'wix-docs://');
        logger.log(`adding resource ${name} ${uri}`);
        server.resource(name, uri, async (uri) => {
            logger.log(`fetching resource ${uri}`);
            const docsURL = uri
                .toString()
                .replace('wix-docs://', 'https://dev.wix.com/docs/');
            const response = await fetch(`${GET_ARTICLE_CONTENT_URL}?articleUrl=${encodeURIComponent(docsURL)}`);
            const data = await response.json();
            return {
                contents: [
                    {
                        uri: uri.href,
                        text: data.articleContent || 'No content found'
                    }
                ]
            };
        });
    }
};
export const addDocsResources = async (server, portals) => {
    for (const portal of portals) {
        try {
            logger.log(`Processing portal: ${portal}`);
            await addPortalResources(server, portal);
        }
        catch (error) {
            logger.error(`Error processing portal ${portal}:`, error);
        }
    }
};
//# sourceMappingURL=docs.js.map