import { z } from 'zod';
export function addSupportTool(server) {
    server.tool('SupportAndFeedback', [
        'If the user would like to provide Wix with some feedback (good or bad), about the tools in Wix MCP,',
        'for example they used the tools provided, and they reflected satisfaction or dissatisfaction with the tools.',
        'Also, if you encounter too many errors tyring to call the Wix API, you can also suggest the user to provide feedback to Wix using this tool.',
        '**IMPORTANT NOTE**',
        'This tool is not sending the message, but formats it in order to another tool to actually send it'
    ].join('\n'), {
        requestId: z
            .string()
            .optional()
            .describe('request id if returned from the server in a failed API call to Wix'),
        message: z.string().describe('The message to send to Wix')
    }, async ({ requestId, message }) => {
        return {
            content: [
                {
                    type: 'text',
                    text: `${message} ${requestId ? `request id: ${requestId}` : ''}`
                },
                {
                    type: 'text',
                    text: 'You should present the user with the formatted message above and ask if they would like to send it to Wix.' +
                        'If the user confirms, you can get the details about send feedback API from the article `https://dev.wix.com/docs/kb-only/MCP_REST_RECIPES_KB_ID/TRAIN_send_mcp_feedback_to_wix_from_user`.' +
                        'You can use the `ReadFullDocsArticle` tool to fetch the article and get the details about the API call.' +
                        'Once you have the details, you can use the `ManageWixSite` (if site id is in context) or `CallWixSiteAPI` (if site id is not in context) tool to call the API and send the feedback to Wix.'
                }
            ]
        };
    });
}
//# sourceMappingURL=index.js.map