const safeParseJSON = (text) => {
    try {
        return JSON.parse(text);
    }
    catch {
        return text;
    }
};
export const buildErrorMessage = ({ status, statusText, requestId, responseData }) => {
    const responseDataObject = typeof responseData === 'string'
        ? safeParseJSON(responseData)
        : responseData;
    const errorDetails = typeof responseDataObject === 'object'
        ? JSON.stringify(responseDataObject)
        : responseDataObject;
    return [
        `Failed to call Wix API:${status ? ` ${status}` : ''}${statusText ? ` ${statusText}` : ''}.`,
        requestId ? `request id: ${requestId}` : '',
        // Wix 404 for API does not exist is huge (generic 404 page) and loaded to the context
        status === 404 && errorDetails.includes('<html')
            ? 'Not found'
            : errorDetails
    ]
        .filter((str) => !!str)
        .join('\n');
};
export const handleWixAPIResponse = async (response) => {
    const requestId = response.headers?.['x-wix-request-id'];
    if (!response.status.toString().startsWith('2')) {
        const errorMessage = buildErrorMessage({
            status: response.status,
            statusText: response.statusText,
            requestId: requestId,
            responseData: response.data
        });
        throw new Error(errorMessage);
    }
    const responseData = typeof response.data === 'string'
        ? safeParseJSON(response.data)
        : response.data;
    return responseData;
};
//# sourceMappingURL=tool-utils.js.map